# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class ItemSource(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'int',
        'part_number': 'str',
        'cost': 'float',
        'description': 'str',
        'is_vendor': 'bool',
        'is_manufacturer': 'bool',
        'contact_info': 'str',
        'url': 'str',
        'item': 'Item',
        'source': 'Source',
        'target_url': 'str',
        'display_url': 'str',
        'is_vendor_string': 'str',
        'is_manufacturer_string': 'str'
    }

    attribute_map = {
        'id': 'id',
        'part_number': 'partNumber',
        'cost': 'cost',
        'description': 'description',
        'is_vendor': 'isVendor',
        'is_manufacturer': 'isManufacturer',
        'contact_info': 'contactInfo',
        'url': 'url',
        'item': 'item',
        'source': 'source',
        'target_url': 'targetUrl',
        'display_url': 'displayUrl',
        'is_vendor_string': 'isVendorString',
        'is_manufacturer_string': 'isManufacturerString'
    }

    def __init__(self, id=None, part_number=None, cost=None, description=None, is_vendor=None, is_manufacturer=None, contact_info=None, url=None, item=None, source=None, target_url=None, display_url=None, is_vendor_string=None, is_manufacturer_string=None, local_vars_configuration=None):  # noqa: E501
        """ItemSource - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._part_number = None
        self._cost = None
        self._description = None
        self._is_vendor = None
        self._is_manufacturer = None
        self._contact_info = None
        self._url = None
        self._item = None
        self._source = None
        self._target_url = None
        self._display_url = None
        self._is_vendor_string = None
        self._is_manufacturer_string = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if part_number is not None:
            self.part_number = part_number
        if cost is not None:
            self.cost = cost
        if description is not None:
            self.description = description
        self.is_vendor = is_vendor
        self.is_manufacturer = is_manufacturer
        if contact_info is not None:
            self.contact_info = contact_info
        if url is not None:
            self.url = url
        if item is not None:
            self.item = item
        if source is not None:
            self.source = source
        if target_url is not None:
            self.target_url = target_url
        if display_url is not None:
            self.display_url = display_url
        if is_vendor_string is not None:
            self.is_vendor_string = is_vendor_string
        if is_manufacturer_string is not None:
            self.is_manufacturer_string = is_manufacturer_string

    @property
    def id(self):
        """Gets the id of this ItemSource.  # noqa: E501


        :return: The id of this ItemSource.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ItemSource.


        :param id: The id of this ItemSource.  # noqa: E501
        :type: int
        """

        self._id = id

    @property
    def part_number(self):
        """Gets the part_number of this ItemSource.  # noqa: E501


        :return: The part_number of this ItemSource.  # noqa: E501
        :rtype: str
        """
        return self._part_number

    @part_number.setter
    def part_number(self, part_number):
        """Sets the part_number of this ItemSource.


        :param part_number: The part_number of this ItemSource.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                part_number is not None and len(part_number) > 64):
            raise ValueError("Invalid value for `part_number`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                part_number is not None and len(part_number) < 0):
            raise ValueError("Invalid value for `part_number`, length must be greater than or equal to `0`")  # noqa: E501

        self._part_number = part_number

    @property
    def cost(self):
        """Gets the cost of this ItemSource.  # noqa: E501


        :return: The cost of this ItemSource.  # noqa: E501
        :rtype: float
        """
        return self._cost

    @cost.setter
    def cost(self, cost):
        """Sets the cost of this ItemSource.


        :param cost: The cost of this ItemSource.  # noqa: E501
        :type: float
        """

        self._cost = cost

    @property
    def description(self):
        """Gets the description of this ItemSource.  # noqa: E501


        :return: The description of this ItemSource.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ItemSource.


        :param description: The description of this ItemSource.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def is_vendor(self):
        """Gets the is_vendor of this ItemSource.  # noqa: E501


        :return: The is_vendor of this ItemSource.  # noqa: E501
        :rtype: bool
        """
        return self._is_vendor

    @is_vendor.setter
    def is_vendor(self, is_vendor):
        """Sets the is_vendor of this ItemSource.


        :param is_vendor: The is_vendor of this ItemSource.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_vendor is None:  # noqa: E501
            raise ValueError("Invalid value for `is_vendor`, must not be `None`")  # noqa: E501

        self._is_vendor = is_vendor

    @property
    def is_manufacturer(self):
        """Gets the is_manufacturer of this ItemSource.  # noqa: E501


        :return: The is_manufacturer of this ItemSource.  # noqa: E501
        :rtype: bool
        """
        return self._is_manufacturer

    @is_manufacturer.setter
    def is_manufacturer(self, is_manufacturer):
        """Sets the is_manufacturer of this ItemSource.


        :param is_manufacturer: The is_manufacturer of this ItemSource.  # noqa: E501
        :type: bool
        """
        if self.local_vars_configuration.client_side_validation and is_manufacturer is None:  # noqa: E501
            raise ValueError("Invalid value for `is_manufacturer`, must not be `None`")  # noqa: E501

        self._is_manufacturer = is_manufacturer

    @property
    def contact_info(self):
        """Gets the contact_info of this ItemSource.  # noqa: E501


        :return: The contact_info of this ItemSource.  # noqa: E501
        :rtype: str
        """
        return self._contact_info

    @contact_info.setter
    def contact_info(self, contact_info):
        """Sets the contact_info of this ItemSource.


        :param contact_info: The contact_info of this ItemSource.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                contact_info is not None and len(contact_info) > 64):
            raise ValueError("Invalid value for `contact_info`, length must be less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                contact_info is not None and len(contact_info) < 0):
            raise ValueError("Invalid value for `contact_info`, length must be greater than or equal to `0`")  # noqa: E501

        self._contact_info = contact_info

    @property
    def url(self):
        """Gets the url of this ItemSource.  # noqa: E501


        :return: The url of this ItemSource.  # noqa: E501
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this ItemSource.


        :param url: The url of this ItemSource.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                url is not None and len(url) > 256):
            raise ValueError("Invalid value for `url`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                url is not None and len(url) < 0):
            raise ValueError("Invalid value for `url`, length must be greater than or equal to `0`")  # noqa: E501

        self._url = url

    @property
    def item(self):
        """Gets the item of this ItemSource.  # noqa: E501


        :return: The item of this ItemSource.  # noqa: E501
        :rtype: Item
        """
        return self._item

    @item.setter
    def item(self, item):
        """Sets the item of this ItemSource.


        :param item: The item of this ItemSource.  # noqa: E501
        :type: Item
        """

        self._item = item

    @property
    def source(self):
        """Gets the source of this ItemSource.  # noqa: E501


        :return: The source of this ItemSource.  # noqa: E501
        :rtype: Source
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this ItemSource.


        :param source: The source of this ItemSource.  # noqa: E501
        :type: Source
        """

        self._source = source

    @property
    def target_url(self):
        """Gets the target_url of this ItemSource.  # noqa: E501


        :return: The target_url of this ItemSource.  # noqa: E501
        :rtype: str
        """
        return self._target_url

    @target_url.setter
    def target_url(self, target_url):
        """Sets the target_url of this ItemSource.


        :param target_url: The target_url of this ItemSource.  # noqa: E501
        :type: str
        """

        self._target_url = target_url

    @property
    def display_url(self):
        """Gets the display_url of this ItemSource.  # noqa: E501


        :return: The display_url of this ItemSource.  # noqa: E501
        :rtype: str
        """
        return self._display_url

    @display_url.setter
    def display_url(self, display_url):
        """Sets the display_url of this ItemSource.


        :param display_url: The display_url of this ItemSource.  # noqa: E501
        :type: str
        """

        self._display_url = display_url

    @property
    def is_vendor_string(self):
        """Gets the is_vendor_string of this ItemSource.  # noqa: E501


        :return: The is_vendor_string of this ItemSource.  # noqa: E501
        :rtype: str
        """
        return self._is_vendor_string

    @is_vendor_string.setter
    def is_vendor_string(self, is_vendor_string):
        """Sets the is_vendor_string of this ItemSource.


        :param is_vendor_string: The is_vendor_string of this ItemSource.  # noqa: E501
        :type: str
        """

        self._is_vendor_string = is_vendor_string

    @property
    def is_manufacturer_string(self):
        """Gets the is_manufacturer_string of this ItemSource.  # noqa: E501


        :return: The is_manufacturer_string of this ItemSource.  # noqa: E501
        :rtype: str
        """
        return self._is_manufacturer_string

    @is_manufacturer_string.setter
    def is_manufacturer_string(self, is_manufacturer_string):
        """Sets the is_manufacturer_string of this ItemSource.


        :param is_manufacturer_string: The is_manufacturer_string of this ItemSource.  # noqa: E501
        :type: str
        """

        self._is_manufacturer_string = is_manufacturer_string

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ItemSource):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ItemSource):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from cdbApi.configuration import Configuration


class LogEntryEditInformation(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'item_id': 'int',
        'log_entry': 'str',
        'effective_date': 'datetime'
    }

    attribute_map = {
        'item_id': 'itemId',
        'log_entry': 'logEntry',
        'effective_date': 'effectiveDate'
    }

    def __init__(self, item_id=None, log_entry=None, effective_date=None, local_vars_configuration=None):  # noqa: E501
        """LogEntryEditInformation - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._item_id = None
        self._log_entry = None
        self._effective_date = None
        self.discriminator = None

        if item_id is not None:
            self.item_id = item_id
        if log_entry is not None:
            self.log_entry = log_entry
        if effective_date is not None:
            self.effective_date = effective_date

    @property
    def item_id(self):
        """Gets the item_id of this LogEntryEditInformation.  # noqa: E501


        :return: The item_id of this LogEntryEditInformation.  # noqa: E501
        :rtype: int
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """Sets the item_id of this LogEntryEditInformation.


        :param item_id: The item_id of this LogEntryEditInformation.  # noqa: E501
        :type: int
        """

        self._item_id = item_id

    @property
    def log_entry(self):
        """Gets the log_entry of this LogEntryEditInformation.  # noqa: E501


        :return: The log_entry of this LogEntryEditInformation.  # noqa: E501
        :rtype: str
        """
        return self._log_entry

    @log_entry.setter
    def log_entry(self, log_entry):
        """Sets the log_entry of this LogEntryEditInformation.


        :param log_entry: The log_entry of this LogEntryEditInformation.  # noqa: E501
        :type: str
        """

        self._log_entry = log_entry

    @property
    def effective_date(self):
        """Gets the effective_date of this LogEntryEditInformation.  # noqa: E501


        :return: The effective_date of this LogEntryEditInformation.  # noqa: E501
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """Sets the effective_date of this LogEntryEditInformation.


        :param effective_date: The effective_date of this LogEntryEditInformation.  # noqa: E501
        :type: datetime
        """

        self._effective_date = effective_date

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LogEntryEditInformation):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LogEntryEditInformation):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Component Database API

    The API that provides access to Component Database data.  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: djarosz@anl.gov
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from cdbApi.api_client import ApiClient
from cdbApi.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class LogApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def get_successful_entity_update_log(self, **kwargs):  # noqa: E501
        """get_successful_entity_update_log  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_successful_entity_update_log(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Log]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_successful_entity_update_log_with_http_info(**kwargs)  # noqa: E501

    def get_successful_entity_update_log_with_http_info(self, **kwargs):  # noqa: E501
        """get_successful_entity_update_log  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_successful_entity_update_log_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Log], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_successful_entity_update_log" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/Logs/System/EntityInfo', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Log]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_successful_entity_update_log_since_entered_date(self, since_date, **kwargs):  # noqa: E501
        """get_successful_entity_update_log_since_entered_date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_successful_entity_update_log_since_entered_date(since_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DateParam since_date: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Log]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_successful_entity_update_log_since_entered_date_with_http_info(since_date, **kwargs)  # noqa: E501

    def get_successful_entity_update_log_since_entered_date_with_http_info(self, since_date, **kwargs):  # noqa: E501
        """get_successful_entity_update_log_since_entered_date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_successful_entity_update_log_since_entered_date_with_http_info(since_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DateParam since_date: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Log], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'since_date'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_successful_entity_update_log_since_entered_date" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'since_date' is set
        if self.api_client.client_side_validation and ('since_date' not in local_var_params or  # noqa: E501
                                                        local_var_params['since_date'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `since_date` when calling `get_successful_entity_update_log_since_entered_date`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'since_date' in local_var_params:
            path_params['sinceDate'] = local_var_params['since_date']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/Logs/System/EntityInfoSinceEnteredDate/{sinceDate}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Log]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_successful_login_log(self, **kwargs):  # noqa: E501
        """get_successful_login_log  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_successful_login_log(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Log]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_successful_login_log_with_http_info(**kwargs)  # noqa: E501

    def get_successful_login_log_with_http_info(self, **kwargs):  # noqa: E501
        """get_successful_login_log  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_successful_login_log_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Log], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_successful_login_log" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/Logs/System/LoginInfo', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Log]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_unsuccessful_entity_update_log(self, **kwargs):  # noqa: E501
        """get_unsuccessful_entity_update_log  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_unsuccessful_entity_update_log(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Log]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_unsuccessful_entity_update_log_with_http_info(**kwargs)  # noqa: E501

    def get_unsuccessful_entity_update_log_with_http_info(self, **kwargs):  # noqa: E501
        """get_unsuccessful_entity_update_log  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_unsuccessful_entity_update_log_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Log], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_unsuccessful_entity_update_log" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/Logs/System/EntityWarning', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Log]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_unsuccessful_entity_update_log_since_entered_date(self, since_date, **kwargs):  # noqa: E501
        """get_unsuccessful_entity_update_log_since_entered_date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_unsuccessful_entity_update_log_since_entered_date(since_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DateParam since_date: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Log]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_unsuccessful_entity_update_log_since_entered_date_with_http_info(since_date, **kwargs)  # noqa: E501

    def get_unsuccessful_entity_update_log_since_entered_date_with_http_info(self, since_date, **kwargs):  # noqa: E501
        """get_unsuccessful_entity_update_log_since_entered_date  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_unsuccessful_entity_update_log_since_entered_date_with_http_info(since_date, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param DateParam since_date: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Log], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'since_date'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_unsuccessful_entity_update_log_since_entered_date" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'since_date' is set
        if self.api_client.client_side_validation and ('since_date' not in local_var_params or  # noqa: E501
                                                        local_var_params['since_date'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `since_date` when calling `get_unsuccessful_entity_update_log_since_entered_date`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'since_date' in local_var_params:
            path_params['sinceDate'] = local_var_params['since_date']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/Logs/System/EntityWarningSinceEnteredDate/{sinceDate}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Log]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_unsuccessful_login_log(self, **kwargs):  # noqa: E501
        """get_unsuccessful_login_log  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_unsuccessful_login_log(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[Log]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_unsuccessful_login_log_with_http_info(**kwargs)  # noqa: E501

    def get_unsuccessful_login_log_with_http_info(self, **kwargs):  # noqa: E501
        """get_unsuccessful_login_log  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_unsuccessful_login_log_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[Log], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_unsuccessful_login_log" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['cdbAuth']  # noqa: E501

        return self.api_client.call_api(
            '/api/Logs/System/LoginWarning', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[Log]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)
